OC.L10N.register(
    "core",
    {
    "Please select a file." : "ファイルを選択してください。",
    "File is too big" : "ファイルが大きすぎます",
    "The selected file is not an image." : "選択されたファイルは画像ではありません",
    "The selected file cannot be read." : "選択されたファイルを読み込めませんでした",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブのサイズを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードされたファイルは、HTMLフォームで指定されたMAX_FILE_SIZEディレクティブ制限を超えています",
    "The file was only partially uploaded" : "ファイルは部分的にしかアップロードされていません",
    "No file was uploaded" : "ファイルがアップロードされていません",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Could not write file to disk" : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張機能がファイルのアップロードを停止しました",
    "Invalid file provided" : "無効なファイルが提供されました",
    "No image or file provided" : "画像またはファイルが提供されていません",
    "Unknown filetype" : "不明なファイル形式",
    "Invalid image" : "無効な画像",
    "An error occurred. Please contact your admin." : "エラーが発生しました。管理者に連絡してください。",
    "No temporary profile picture available, try again" : "一時的なプロファイル用画像が利用できません。もう一度試してください",
    "No crop data provided" : "クロップデータが提供されていません",
    "No valid crop data provided" : "有効なクロップデータが提供されていません",
    "Crop is not square" : "クロップが正方形ではありません",
    "State token does not match" : "状態トークンが一致しません",
    "Invalid app password" : "アプリパスワードが無効です",
    "Could not complete login" : "ログインが完了できませんでした",
    "Your login token is invalid or has expired" : "あなたのログイントークンは無効か期限が切れています。",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "このコミュニティリリースのNextcloudは未サポートです。インスタント通知も利用できません。",
    "Password reset is disabled" : "パスワードリセットは無効化されています",
    "Could not reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
    "Could not reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
    "%s password reset" : "%s パスワードリセット",
    "Password reset" : "パスワードのリセット",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "次のボタンをクリックして、パスワードをリセットしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "パスワードをリセットするには、次のリンクをクリックしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
    "Reset your password" : "パスワードをリセット",
    "Nextcloud Server" : "Nextcloud サーバー",
    "Some of your link shares have been removed" : "リンク共有の一部が削除されました",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "セキュリティ上の不具合により、あなたのリンク共有をいくつか削除する必要がありました。 詳しくはリンクをご覧ください。",
    "The user limit of this instance is reached." : "このインスタンスのユーザー制限に達しました。",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "サブスクリプションキーを入力して、ユーザー制限を増やします。 Nextcloud Enterpriseの詳細については、当社のWebサイトを参照してください。",
    "Preparing update" : "アップデートの準備中",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "修復ステップ:",
    "Repair info:" : "修復情報:",
    "Repair warning:" : "修復警告:",
    "Repair error:" : "修復エラー:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php で自動更新が無効になっているので、コマンドラインでの更新を利用してください。",
    "[%d / %d]: Checking table %s" : "[%d / %d]: テーブル %s をチェック中",
    "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
    "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
    "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
    "Updating database schema" : "データベースのスキーマを更新",
    "Updated database" : "データベース更新済み",
    "Update app \"%s\" from App Store" : "アプリストアから \"%s\" アプリをアップデートする",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマ %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
    "Updated \"%1$s\" to %2$s" : "%1$sを%2$sに更新しました",
    "Set log level to debug" : "ログをデバッグレベルに設定",
    "Reset log level" : "ログレベルをリセット",
    "Starting code integrity check" : "コード整合性の確認を開始",
    "Finished code integrity check" : "コード整合性の確認が終了",
    "%s (incompatible)" : "%s (非互換)",
    "The following apps have been disabled: %s" : "次のアプリが無効になりました: %s ",
    "Already up to date" : "すべて更新済",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHPのシステム環境変数が正しく設定されていないようです。getenv(\"PATH\") コマンドでテストして何も値を返さないことを確認してください。",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "特にphp-fpmを使用する場合は、{linkstart}インストールドキュメント↗{linkend}でPHP構成に関する注意事項とサーバーのPHP構成を確認してください。",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "\"config\"は読み取り専用になってます。そのためにWEBインターフェースで設定できません可能性があります。さらに、更新時に\"config\"ファイルを書き込み権限を与えることが必要",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "あなたのデータベースは \"READ COMMITED\" トランザクション分離レベルで動作していません。このことにより複数のアクションが平行して実行される場合に問題が起こる可能性があります。",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP のモジュール 'fileinfo' が見つかりません。mimeタイプの検出を精度良く行うために、このモジュールを有効にすることを強くお勧めします。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "トランザクションファイルロックが無効になっているため、競合状態に問題が発生する可能性があります。これらの問題を回避するには、config.phpで \"filelocking.enabled\" を有効にします。詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "インストールがドメインのルートにインストールされておらず、システムクーロンを使用している場合は、URLの生成に問題がある可能性があります。 これらの問題を回避するには、config.phpファイルの \"overwrite.cli.url\"オプションをインストールのWebルートパスに設定してください（提案： \"{suggestedOverwriteCliURL}\"）。",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ご使用のシステムには、デフォルトの電話地域が設定されていません。これは、国コードなしでプロファイル設定の電話番号を検証するために必要です。国コードなしで番号を許可するには、地域のそれぞれの{linkstart} ISO3166-1コード↗{linkend}とともに \"default_phone_region\" を設定ファイルに追加してください。",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI から cronジョブを実行することができませんでした。次の技術的なエラーが発生しています：",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後のバックグラウンドジョブの実行は{relativeTime}を実行しました。何かがおかしいようです。 {linkstart}バックグラウンドジョブの設定を確認してください↗{linkend}。",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "このサーバーはNextcloudの未サポートのコミュニティビルドです。このインスタンスのサイズでは、パフォーマンス、信頼性、スケーラビリティは保証されません。サービスに負荷をかけないように、プッシュ通知は無効になっています。Nextcloud Enterpriseのメリットについては、nextcloud.com/enterprise をご覧ください。",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "このサーバーにはインターネット接続がありません。複数のエンドポイントに到達できませんでした。 つまり、外部ストレージのマウント、アップデートに関する通知、サードパーティ製アプリのインストールなどの機能の一部は機能しません。 リモートからファイルにアクセスしたり、通知メールを送信したりすることもできません。インターネットへの接続を確立できれば、すべての機能を利用することができます。",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "メモリーキャッシュが構成されていません。パフォーマンスを向上させるために、可能な場合はmemcacheを構成してください。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHPで利用する乱数に適切なソースがありません。これは、セキュリティ上の理由から全く推奨されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "あなたは現在、PHP {version} を使用しています。ディストリビューションでサポートされたら、すぐにPHPのバージョンをアップグレードして、{linkstart}PHPグループ↗の提供するパフォーマンスとセキュリティメリット{linkend}を享受してください。",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23は、PHP7.3をサポートする最後のリリースです。 Nextcloud24には少なくともPHP7.4が必要です。",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "リバースプロキシヘッダーの構成が正しくないか、信頼できるプロキシからNextcloudにアクセスしています。そうでない場合、これはセキュリティに問題があり、攻撃者がNextcloudを表示できるようにIPアドレスを偽装することができます。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcachedが分散キャッシュとして設定されていますが、間違ったPHPモジュール \"memcache\" がインストールされています。 \\OC\\Memcache\\Memcachedは \"memcached\" のみをサポートし、\"memcache\" はサポートしません。は、{linkstart} 両方のモジュールについてはmemcached wiki↗{linkend}を参照してください。",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "一部のファイルは整合性チェックに合格していません。この問題を解決する方法の詳細については、{linkstart1}ドキュメント↗{linkend}をご覧ください。 ({linkstart2}無効なファイルのリスト…{linkend} / {linkstart3}再スキャン…{linkend})",
    "The PHP OPcache module is not properly configured:" : "PHP OPcacheモジュールが適切に構成されていません: ",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 関数 \"set_time_limit\" は使用できません。これにより実行スクリプトが途中で停止されて、インストールを破壊する可能性があります。この機能を有効にすることを強くお勧めします。",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "プロフィール写真と設定インターフェースが壊れているため、PHPはFreeTypeをサポートしていません。",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "テーブル \"{tableName}\"のインデックス \"{indexName}\"が見つかりません。",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "データベースにいくつかのインデックスがありません。 大きなテーブルにインデックスを追加すると、自動的に追加されないまでに時間がかかる可能性があるためです。 \"occ db:add-missing-indices\"を実行することによって、インスタンスが実行し続けている間にそれらの欠けているインデックスを手動で追加することができます。 インデックスが追加されると、それらのテーブルへのクエリは通常はるかに速くなります。",
    "Missing primary key on table \"{tableName}\"." : "テーブル \"{tableName}\"にプライマリーキーがありません。",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "データベースにいくつかのプライマリーキーがありません。大きなテーブルにプライマリーキーを追加するには時間がかかる可能性があるため、自動的に追加されません。 \"occ db:add-missing-primary-keys\" を実行することにより、インスタンスを動かしたままで足りないプライマリーキーを手動で追加することができます。",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "テーブル \"{tableName}\" にオプションのカラム \"{columnName}\" が存在しません。",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "データベースにはオプションのカラムがいくつかありません。大きなテーブルにカラムを追加するには時間がかかるため、オプションのカラムは自動的に追加されませんでした。\"occ db:add-missing-columns\"を実行することで、不足しているカラムはインスタンスの実行中に手動で追加することができます。カラムが追加されると、応答性や使い勝手が改善される可能性があります。",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "このインスタンスには推奨されるPHPモジュールがいくつかありません。 パフォーマンスの向上と互換性の向上のために、それらをインストールすることを強くお勧めします。",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "このインスタンスのphp-imagickモジュールはSVGをサポートしていません。互換性の向上のために、インストールすることをお勧めします。",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベースの一部のカラムがbigintへ変換されていません。大きなテーブルのカラムタイプの変更には時間がかかる可能性があるため、自動的には変更されませんでした。 'occ db:convert-filecache-bigint' を実行することにより、これらの保留中の変更を手動で適用できます。この操作は、インスタンスがオフラインのときに実行する必要があります。詳細については、{linkstart}これに関するドキュメントページ↗{linkend}をお読みください。",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLiteがデータベースとして使用されています。大規模な運用では別のデータベースに切り替えることをお勧めします。",
    "This is particularly recommended when using the desktop client for file synchronisation." : "これは、ファイル同期にデスクトップクライアントを使用する場合に特に推奨されます。",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "別のデータベースに移行するには、コマンドラインツール 'occ db:convert-type'を使用するか、{linkstart}ドキュメント↗{linkend}を参照してください。",
    "The PHP memory limit is below the recommended value of 512MB." : "PHPのメモリ制限が推奨値の512MB以下です。",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "一部のアプリディレクトリは、Webサーバーディレクトリとは異なるユーザーによって所有されています。 アプリが手動でインストールされた場合、これがそのケースに値します。 次のアプリディレクトリの権限を確認します。",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベースとしてMySQLを使用していますが、4バイト文字をサポートしていません。ファイル名やコメントなどで4バイト文字（絵文字など）を問題なく扱うためには、MySQLで4バイトサポートを有効にすることが推奨されます。詳細は{linkstart}これに関するドキュメントページ↗{linkend}をお読みください。",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "このインスタンスは、S3ベースのオブジェクトストアをプライマリストレージとして使用します。 アップロードされたファイルは一時的にサーバーに保存されるため、PHPの一時ディレクトリに50 GBの空き容量を確保することをお勧めします。 パスと空き容量についての完全な詳細はログを確認してください。 一時ディレクトリを修正するには、php.iniの一時ディレクトリを変更するか、またはそのパスでより多くのスペースを利用できるようにしてください。",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "このインスタンスで指定している一時ディレクトリは、存在しないか書き込みできないディレクトリです。",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "安全な接続でインスタンスにアクセスしていますが、インスタンスは安全でないURLを生成しています。これは、リバースプロキシの背後にあり、構成設定変数が正しく上書きされていない可能性があります。これについては、{linkend}ドキュメントページ↗{linkstart}をお読みください。",
    "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "データディレクトリやファイルがインターネットからアクセスされている可能性があります。.htaccessファイルが機能していません。データディレクトリにアクセスできないようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外に移動することを強くお勧めします。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 一部の機能は正しく機能しない可能性があります。この設定を調整することを推奨します。",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーに \"{expected}\"が含まれていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTPヘッダの\"{header}\"に\"{val1}\"、\"{val2}\"、\"{val3}\"、\"{val4}\"、\"{val5}\"が設定されていません。これにより、リファラー情報が漏洩する可能性があります。 {linkstart} W3C勧告↗{linkend}を参照してください。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Strict-Transport-Security \"HTTP ヘッダーの秒数が少なくとも\"{seconds}\" に設定されていません。セキュリティを強化するには、{linkstart}セキュリティのヒント↗{linkend}で説明されているようにHSTSを有効にすることをお勧めします。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "安全ではないHTTPでサイトにアクセスしています。 {linkstart}セキュリティのヒント↗{linkend}で説明されているように、代わりにHTTPSを要求するようにサーバーを設定することを強くお勧めします。",
    "unknown text" : "不明なテキスト",
    "Hello world!" : "Hello world!",
    "sunny" : "快晴",
    "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
    "Hello {name}" : " {name}さん､こんにちは",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>これが検索結果です<script>alert(1)</script></strong>",
    "new" : "新規",
    "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "更新が進行中です。このページを離れると一部の環境では処理が中断されてしまう可能性があります。",
    "Update to {version}" : "{version} にアップデート",
    "An error occurred." : "エラーが発生しました。",
    "Please reload the page." : "ページをリロードしてください。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "アップデートできませんでした。<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud コミュニティ</a> に問題を報告してください。",
    "Continue to {productName}" : "{productName} に進む",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
    "Log in" : "ログイン",
    "Logging in …" : "ログイン中...",
    "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
    "Please contact your administrator." : "管理者にお問い合わせください。",
    "An internal error occurred." : "内部エラーが発生しました。",
    "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
    "Username or email" : "ユーザー名またはメールアドレス",
    "Password" : "パスワード",
    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
    "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
    "User disabled" : "ユーザーは無効です",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
    "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
    "Browser not supported" : "サポートされていないブラウザーです",
    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
    "Your connection is not secure" : "この接続は安全ではありません",
    "Passwordless authentication is only available over a secure connection." : "パスワードレス認証は、セキュアな接続でのみ利用可能です。",
    "Reset password" : "パスワードをリセット",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "このアカウントのメールアドレスにパスワードリセットメッセージを送信しました。届かない場合は、スパム/ジャンクフォルダーを確認するか、ローカル管理者にサポートを依頼してください。",
    "If it is not there ask your local administrator." : "もしそうでない場合は、管理者に問い合わせてください。",
    "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
    "Password cannot be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
    "Back to login" : "ログインに戻る",
    "New password" : "新しいパスワードを入力",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ファイルが暗号化されます。パスワードがリセットされた後は、データを元に戻すことはできません。対処方法がわからない場合は、続行する前に管理者に問い合わせてください。本当に続行しますか?",
    "I know what I'm doing" : "どういう操作をしているか理解しています",
    "Resetting password" : "パスワードのリセット",
    "Install recommended apps" : "推奨アプリをインストール",
    "Recommended apps" : "推奨アプリ",
    "Loading apps …" : "アプリを読み込み中…",
    "Could not fetch list of apps from the App Store." : "App Storeからアプリのリストを取得できませんでした。",
    "Installing apps …" : "アプリをインストールしています…",
    "App download or installation failed" : "アプリのダウンロードまたはインストールに失敗しました",
    "Cannot install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
    "Cannot install this app" : "このアプリはインストールできません",
    "Cancel" : "キャンセル",
    "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
    "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ファイル、連絡先、カレンダーとうまく合わさったシンプルなメールアプリ。",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
    "Collaboratively edit office documents." : "Office 文書を共同で編集します。",
    "Local document editing back-end used by the Collabora Online app." : "Collabora Onlineアプリで使用されるローカルドキュメント編集バックエンド",
    "Forgot password?" : "パスワードをお忘れですか?",
    "Log in with a device" : "デバイスを使ってログインする",
    "Back" : "戻る",
    "Login form is disabled." : "ログインフォームは無効です。",
    "Edit Profile" : "プロフィールを編集",
    "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
    "You have not added any info yet" : "まだ情報が追加されていません",
    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
    "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
    "Reset search" : "検索をリセットする",
    "Search for {name} only" : "{name}のみを検索",
    "No results for {query}" : "{query}の検索結果はありません",
    "Start typing to search" : "入力して検索を開始します",
    "Loading more results …" : "次の結果を読み込み中 ...",
    "Load more results" : "次の結果を読み込む",
    "Search" : "検索",
    "An error occurred while searching for {type}" : "{type} の検索中にエラーが発生しました",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["検索には、{minSearchLength}文字以上が必要です"],
    "Search {types} …" : "{types} を検索…",
    "Settings" : "設定",
    "Could not load your contacts" : "連絡先を読み込めませんでした",
    "Search contacts …" : "連絡先を検索...",
    "No contacts found" : "連絡先が見つかりません",
    "Show all contacts …" : "すべての連絡先を表示...",
    "Install the Contacts app" : "連絡先アプリをインストール",
    "Loading your contacts …" : "連絡先を読み込み中...",
    "Looking for {term} …" : "{term} を確認中 ...",
    "No" : "いいえ",
    "Yes" : "はい",
    "No files in here" : "ここにはファイルがありません",
    "New folder" : "新しいフォルダー",
    "No more subfolders in here" : "ここにはサブフォルダーはありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Choose" : "選択",
    "Copy" : "コピー",
    "Move" : "移動",
    "Error loading file picker template: {error}" : "ファイル選択テンプレートの読み込みエラー: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
    "read-only" : "読み取り専用",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} ファイルが競合"],
    "One file conflict" : "1ファイルが競合",
    "New Files" : "新しいファイル",
    "Already existing files" : "既存のファイル",
    "Which files do you want to keep?" : "どちらのファイルを保持しますか？",
    "If you select both versions, the copied file will have a number added to its name." : "両方のバージョンを選択した場合は、ファイル名の後ろに数字を追加したファイルのコピーを作成します。",
    "Continue" : "続ける",
    "(all selected)" : "(すべて選択)",
    "({count} selected)" : "({count} 選択)",
    "Error loading file exists template" : "既存ファイルのテンプレートの読み込みエラー",
    "Pending" : "保留中",
    "Copy to {folder}" : "{folder}へコピー",
    "Move to {folder}" : "{folder}へ移動",
    "Saving …" : "保存中...",
    "Authentication required" : "認証が必要です",
    "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
    "Confirm" : "確認",
    "Failed to authenticate, try again" : "認証に失敗しました。もう一度お試しください",
    "seconds ago" : "数秒前",
    "Connection to server lost" : "サーバーとの接続が切断されました",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["ページの読み込み中に問題が発生しました。%n秒後に再読み込みします"],
    "Add to a project" : "プロジェクトに追加",
    "Show details" : "詳細を表示",
    "Hide details" : "詳細を隠す",
    "Rename project" : "プロジェクト名を変更",
    "Failed to rename the project" : "プロジェクト名の変更に失敗",
    "Failed to create a project" : "プロジェクトの作成に失敗",
    "Failed to add the item to the project" : "プロジェクトへのアイテムの追加に失敗",
    "Connect items to a project to make them easier to find" : "アイテムをプロジェクトに接続して見つけやすくする",
    "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
    "New in" : "新機能",
    "View changelog" : "変更履歴を確認する",
    "Very weak password" : "非常に弱いパスワード",
    "Weak password" : "弱いパスワード",
    "So-so password" : "まずまずのパスワード",
    "Good password" : "良好なパスワード",
    "Strong password" : "強いパスワード",
    "No action available" : "操作できません",
    "Error fetching contact actions" : "連絡先操作取得エラー",
    "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
    "restricted" : "制限済",
    "invisible" : "不可視",
    "Delete" : "削除",
    "Rename" : "名前の変更",
    "Collaborative tags" : "コラボタグ",
    "No tags found" : "タグが見つかりません",
    "Personal" : "個人",
    "Users" : "ユーザー",
    "Apps" : "アプリ",
    "Admin" : "管理",
    "Help" : "ヘルプ",
    "Access forbidden" : "アクセスが禁止されています",
    "Profile not found" : "プロフィールが見つかりません",
    "The profile does not exist." : "プロフィールはありません",
    "Back to %s" : "%s に戻る",
    "File not found" : "ファイルが見つかりません",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ドキュメントはサーバー上に見つかりませんでした。 共有が削除されたか、期限が切れている可能性があります。",
    "Too many requests" : "要求が多すぎます",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
    "Error" : "エラー",
    "Previous" : "前へ",
    "Internal Server Error" : "内部サーバーエラー",
    "The server was unable to complete your request." : "サーバーは要求を完了できませんでした。",
    "If this happens again, please send the technical details below to the server administrator." : "再びこのようなことが起こった場合は、以下の技術情報をサーバー管理者に送ってください。",
    "More details can be found in the server log." : "詳細は、サーバーのログを確認してください。",
    "Technical details" : "技術詳細",
    "Remote Address: %s" : "リモートアドレス: %s",
    "Request ID: %s" : "リクエスト ID: %s",
    "Type: %s" : "種類: %s",
    "Code: %s" : "コード: %s",
    "Message: %s" : "メッセージ: %s",
    "File: %s" : "ファイル: %s",
    "Line: %s" : "行: %s",
    "Trace" : "トレース",
    "Security warning" : "セキュリティ警告",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
    "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
    "Username" : "ユーザー名",
    "Show password" : "パスワードを表示",
    "Storage & database" : "ストレージとデータベース",
    "Data folder" : "データフォルダー",
    "Configure the database" : "データベースを設定してください",
    "Only %s is available." : "%s のみ有効です。",
    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
    "Database user" : "データベースのユーザー名",
    "Database password" : "データベースのパスワード",
    "Database name" : "データベース名",
    "Database tablespace" : "データベースの表領域",
    "Database host" : "データベースのホスト名",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
    "Performance warning" : "パフォーマンス警告",
    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
    "Install" : "インストール",
    "Installing …" : "インストールしています…",
    "Need help?" : "ヘルプが必要ですか？",
    "See the documentation" : "ドキュメントを確認してください",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloudを再インストールしようとしているようです。 しかし、CAN_INSTALLファイルがconfigディレクトリにありません。 続行するには、configフォルダーにCAN_INSTALLファイルを作成してください。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "設定フォルダーからCAN_INSTALLを削除できませんでした。 このファイルを手動で削除してください。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
    "Get your own free account" : "無料でアカウントを作成",
    "Skip to main content" : "メインコンテンツへスキップ",
    "Skip to navigation of app" : "アプリのナビゲーションにスキップする",
    "More apps" : "さらにアプリ",
    "More" : "もっと見る",
    "More apps menu" : "その他のアプリメニュー",
    "Contacts" : "連絡先",
    "Contacts menu" : "連絡先メニュー",
    "Settings menu" : "メニュー設定",
    "Confirm your password" : "パスワードを確認",
    "Connect to your account" : "あなたのアカウントに接続する",
    "Please log in before granting %1$s access to your %2$s account." : "あなたの %2$s アカウントに %1$s アクセスを許可する前にログインしてください。",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "新しいデバイスやアプリを設定しようとしていないのに、今この画面が表示された場合、誰かがあなたを騙してデータへのアクセス権を奪取しようとしています。その場合は、ここで止めてシステム管理者に連絡してください。",
    "App token" : "アプリのトークン",
    "Grant access" : "アクセスを許可",
    "Alternative log in using app token" : "アプリトークンを使って代替ログイン",
    "Account access" : "アカウントによるアクセス許可",
    "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
    "Account connected" : "アカウント接続済",
    "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
    "You can close this window." : "このウィンドウは閉じてしまって構いません。",
    "This share is password-protected" : "この共有はパスワードで保護されています",
    "The password is wrong. Try again." : "パスワードが違います。再入力してください",
    "Go to %s" : "%sに移動",
    "Two-factor authentication" : "二要素認証",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "このアカウントは強化セキュリティが適用されています。二要素認証を行ってください。",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "有効な二要素認証方式のうち少なくとも1つをロードできませんでした。 管理者に連絡してください。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "二要素認証が強制されていますが、アカウントに設定されていません。 不明な点は管理者に連絡してください。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "二要素認証が強制されていますが、アカウントに設定されていません。 二要素認証をセットアップしてください。",
    "Set up two-factor authentication" : "二要素認証を設定",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "二要素認証が強制されていますが、アカウントに設定されていません。 バックアップコードを使用してログインするか、不明点は管理者に連絡してください。",
    "Use backup code" : "バックアップコードを使用する",
    "Cancel login" : "ログインをキャンセル",
    "Setup two-factor authentication" : "二要素認証を設定",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "アカウントのセキュリティ強化が必要です。使用する認証手段を選択してください。",
    "Error while validating your second factor" : "第二要素の検証でエラーが発生しました",
    "Access through untrusted domain" : "信頼できないドメインを介したアクセス",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "管理者に連絡してください。 管理者の場合は、config.sample.phpを参照して config/config.phpの \"trusted_domains\" を設定してください。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "これを構成する方法の詳細は、%1$sドキュメント%2$sにあります。",
    "App update required" : "アプリの更新が必要",
    "%1$s will be updated to version %2$s" : "%1$s は バーション %2$s にアップデートされます",
    "The following apps will be updated:" : "以下のアプリはアップデートされます:",
    "These incompatible apps will be disabled:" : "無効になる互換性のないアプリ:",
    "The theme %s has been disabled." : "テーマ %s が無効になっています。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
    "Start update" : "アップデートを開始",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで次のコマンドを実行することもできます。",
    "Detailed logs" : "詳細ログ",
    "Update needed" : "更新が必要です",
    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "不明な場合、  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ドキュメント</a>を参照してください。",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Web 画面から続行すると危険性があることを理解しています。この操作がタイムアウトすると、データが失われる危険性があることを理解しています。もし失敗した場合には取得済みのバックアップから修復する方法を理解しています。",
    "Upgrade via web on my own risk" : "危険性を理解した上でWeb画面からアップグレード",
    "Maintenance mode" : "メンテナンスモード",
    "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
    "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
    "Couldn't reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
    "Couldn't reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
    "Checked database schema update" : "指定データベースのスキーマを更新",
    "Checking updates of apps" : "アプリの更新をチェックしています。",
    "Checking for update of app \"%s\" in appstore" : "アプリストアで \"%s\" アプリのアップデートを確認しています",
    "Update app \"%s\" from appstore" : "アプリストアから \"%s\" アプリをアップデートする",
    "Checked for update of app \"%s\" in appstore" : "アプリストアで \"%s\" アプリのアップデートを確認済",
    "Checked database schema update for apps" : "アプリの指定データベースのスキーマを更新",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Webサーバーは適切にホスト名 \"{url}\" が引けるように設定されていません。より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>を参照ください。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーは \"{url}\"を解決するための正しい設定がなされていません。 これは、このフォルダーを直接配信するように更新されていないWebサーバー構成に関連している可能性があります。 あなたの設定と、Apache用の \".htaccess\"、あるいはNginxのドキュメントの  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメントページ</a> に記載されているものとを比較してください。Nginxでは、これらは通常 \"location〜\"で始まる行で更新が必要です。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Webサーバーが.woff2ファイルを配信するように正しく設定されていません。 これは通常Nginx設定の問題です。 Nextcloud 15では、.woff2ファイルも配信するための調整が必要です。 あなたのNginxの設定を<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>の推奨される設定と比較してください。",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "PHP設定の注意事項と php-fpmを利用する場合のサーバー向け設定を<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">インストールドキュメント↗</a>で確認してください。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "ファイルの書き込み時のロックが無効になっており、競合時に問題となる可能性があります。この問題を避ける為に config.php 中の 'filelocking.enabled' を有効にしてください。詳細については、 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント ↗</a> を参照してください。",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "最後のバックグラウンドジョブの実行は{relativeTime}でした。 何かが間違っているようです。",
    "Check the background job settings" : "バックグラウンドジョブの設定を確認する",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "このサーバーにはインターネット接続がありません。複数のエンドポイントに到達できませんでした。 つまり、外部ストレージのマウント、アップデートに関する通知、サードパーティ製アプリのインストールなどの機能の一部は機能しません。 リモートからファイルにアクセスしたり、通知メールを送信したりすることもできません。 このサーバーからインターネットへの接続を確立して、すべての機能を利用してください。",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。可能であれば、パフォーマンスを向上するため、memcacheを設定してください。より詳しい情報は<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>で参照できます。",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "セキュリティ上の理由から推奨されていない為、PHPで利用できる乱数用ソースがありません。 より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>を参照ください。",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "このサーバーでは、{version} のPHPを利用しています。パフォーマンスとセキュリティ上のメリットがあるため利用中のディストリビューションで<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">PHP グループの提供する最新のPHPのバージョン</a>になるべく早くアップグレードすることを強くお勧めします。",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20は、PHP7.2をサポートする最後のリリースです。 Nextcloud21には最低でもPHP7.3が必要です。",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "リバースプロキシヘッダーの設定が正しくないか、信頼できるプロキシからNextcloudにアクセスしています。 そうでない場合、これはセキュリティの問題であり、攻撃者はNextcloudに見えるように自分のIPアドレスを偽装することができます。より詳しい情報は<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>で参照できます。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。 \\OC\\Memcache\\Memcached は、\"memcache\" ではなく、\"memcached\" のみをサポートしています。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki で両方のモジュールの情報</a>について確認してください。",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "いくつかのファイルでチェックサムが適合しませんでした。この問題を解決するためは、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント</a>の詳細を見てください。(<a href=\"{codeIntegrityDownloadEndpoint}\">不適合ファイルのリスト… </a>/ <a href=\"{rescanEndpoint}\">再チェック…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP OPcacheモジュールがロードされていません。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">よりパフォーマンスを向上させる</a>には、PHPインストールにロードすることをお勧めします。",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcacheが適切に設定されていません。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">よりパフォーマンスを向上させる</a>には、<code>php.ini</code>で次の設定を推奨します:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "データベース内のいくつかの列で、big intへの変換が行われていません。 大きなテーブルでカラムタイプを変更すると時間がかかることがあるため、自動的には変更されませんでした。 'occ db：convert-filecache-bigint'を実行することによって、それらの保留中の変更は手動で適用できます。 この操作は、インスタンスがオフラインの間に行う必要があります。 詳細については<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">これに関するドキュメントページを読んでください。</a>",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "他のデータベースに移行する場合はコマンドラインツール: 'occ db:convert-type' を使うか、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメント ↗</a>を参照してください。",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "組み込みのphpメーラーの使用はサポートされていません。 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">メールサーバーの設定を更新してください。↗<a/>",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQLをデータベースとして使用していますが、4バイト文字をサポートしていません。たとえば、ファイル名やコメントの問題なしに（絵文字のような）4バイト文字を処理できるようにするには、MySQLで4バイトサポートを有効にすることをお勧めします。 詳細については<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">これに関するドキュメントページを読んでください。</a>",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "安全な接続でインスタンスにアクセスしていますが、インスタンスが安全でない URL を生成しています。これは、リバースプロキシの後ろにいて、上書き設定変数が正しく設定されていない可能性が高いです。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">これに関するドキュメントのページ</a>を読んでください。",
    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "詳細は <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ドキュメンテーション</a> を参照してください。",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "あなたのデータディレクトリとファイルはおそらくインターネットからアクセス可能です。 .htaccessファイルが機能していません。 データディレクトリにアクセスできなくなるようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外側に移動することを強くお勧めします。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "\"{header}\" HTTPヘッダーが \"{val1}\"、 \"{val2}\"、 \"{val3}\"、 \"{val4}\"、または \"{val5}\"に設定されていません。 これにより、参照元情報が漏れる可能性があります。 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C勧告↗</a>を参照してください。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTPヘッダが最低でも \"{seconds}\" 秒に設定されていません。セキュリティを強化するには、<a href=\"{docUrl}\" rel=\"noreferrer noopener\">セキュリティTips ↗</a>で解説しているHSTSを有効にすることを推奨します。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "セキュアではないHTTP経由でアクセスしています。<a href=\"{docUrl}\">セキュリティTips ↗</a>で述べているように、代わりにHTTPSを必要とするようサーバーを設定することを強くおすすめします。",
    "Continue to Nextcloud" : "Nextcloud に進む",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["アップデートに成功しました。 %n 秒後に Nextcloud にリダイレクトします。"],
    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "このアカウントのメールアドレスにパスワードをリセットするメールが送信されました。 メールが届かなかった場合はあなたのスパム/ジャンクフォルダーをチェックするか、管理者に問い合わせてください。",
    "Password can not be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
    "Could not fetch list of apps from the app store." : "App Storeからアプリのリストを取得できませんでした。",
    "Can't install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
    "Can't install this app" : "このアプリはインストールできません",
    "Calendar, Contacts, Talk, Mail & Collaborative editing" : "カレンダー、連絡先、トーク、メール、共同編集",
    "Finish setup" : "セットアップを完了します",
    "Finishing …" : "作業を完了しています ...",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcacheモジュールがロードされていません。 {linkstart}パフォーマンスを向上させるには、↗{linkend}をPHPインストールにロードすることをお勧めします。",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache モジュールが正しく設定されていません。{linkstart}パフォーマンスを向上させるためには、{linkend} <code>php.ini</code>で以下の設定を使用することを推奨します:"
},
"nplurals=1; plural=0;");
